![vandal-header](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandal.jpg)

vandal Manifesto
=====

1. This library, once and for all, belongs to the vandal framework.

2. Vandal framework consists of vandal, duality and logistics libraries and is open for new ideas.

3. Vandal framework follows PEP8 recommendations, but not blindly and unconditionally.

4. Everyone is allowed to contribute to the project and improve it under the conditions set by the LICENSE.

David Kundih
13.06.2022.
